@@ -6,6 +6,11 @@ set.seed(1)
 # Run code
 ###############################################
 default <- simulate_poisson()
+
+model <- glm(formula = Y ~ X1 + X2, data = default, family = poisson())
+params <- c(0.5, 1)
+params <- c(max(params), params)
+
 test_that("Run default. Check structure.", {
   expect_true(all(class(default) == c("tbl_df", "tbl", "data.frame")))
   expect_true(nrow(default) == 10000)
@@ -14,8 +19,9 @@ test_that("Run default. Check structure.", {
   expect_true(max(default$X1) <= 2)
   expect_true(min(default$X2) >= 1)
   expect_true(max(default$X2) <= 2)
+  expect_true(all(max(abs(model$coefficients - params)) <= .1))
 })
-rm(default)
+rm(default, model, params)
 
 test_that("Returns the correct number of rows.", {
   expect_equal(nrow(simulate_poisson(N = 10)), 10)
