@@ -1,5 +1,6 @@
 context("simulate_tweedie")
 library(GlmSimulatoR)
+library(cplm, quietly = TRUE)
 set.seed(1)
 
 ###############################################
@@ -15,6 +16,17 @@ test_that("Run default. Check structure.", {
 })
 rm(default)
 
+temp <- simulate_tweedie(N = 10000, link = "identity")
+
+model <- cpglm(formula = Y ~ X1, data = temp, link = "identity")
+params <- c(0.02)
+params <- c(max(params), params)
+
+test_that("Check weights", {
+  expect_true(all(max(abs(model$coefficients - params)) <= .2))
+})
+rm(temp, model, params)
+
 test_that("Returns the correct number of rows.", {
   expect_equal(nrow(simulate_tweedie(N = 10)), 10)
   expect_equal(nrow(simulate_tweedie(N = 100)), 100)
